=======
Autores
=======

Si usted es un colaborador activo de este proyecto, agregue una entrada en el archivo CONTRIBUTORS (se encuentra en el directorio raíz del proyecto), siguiendo el formato::

	[1er nombre] [2do nombre] [1er apellido] [2do apellido] [<CORREO>], Twitter: [@Cuenta]

Las siguientes personas han trabajado en este proyecto y son titulares de derecho de autor (en orden alfabético):

.. literalinclude:: ../../../../CONTRIBUTORS
